#!/usr/bin/env python
#
# Lara Maia <dev@lara.monster> 2015 ~ 2023
#
# The Steam Tools NG is free software: you can redistribute it and/or
# modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation, either version 3 of
# the License, or (at your option) any later version.
#
# The Steam Tools NG is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see http://www.gnu.org/licenses/.
#
import asyncio
import contextlib
import functools
import itertools
import logging
from typing import Any, Optional, Dict, Callable, List

import aiohttp
from gi.repository import Gio, Gtk

from stlib import universe, login, community, webapi, internals, plugins
from . import about, settings, window, utils
from . import login as gtk_login
from .. import config, i18n, core

_ = i18n.get_translation
log = logging.getLogger(__name__)


def while_window_realized(function: Callable[..., Any]) -> Callable[..., Any]:
    @functools.wraps(function)
    async def wrapper(self: 'SteamToolsNG', *args: Any, **kwargs: Any) -> None:
        while self.main_window.get_realized():
            await function(self, *args, **kwargs)

    return wrapper


# noinspection PyUnusedLocal
class SteamToolsNG(Gtk.Application):
    def __init__(self) -> None:
        super().__init__(application_id="monster.lara.SteamToolsNG",
                         flags=Gio.ApplicationFlags.FLAGS_NONE)
        self._main_window_id = 0
        self.gtk_settings = Gtk.Settings.get_default()

        self.api_login: Optional[login.Login] = None
        self.api_url = config.parser.get("steam", "api_url")

        self.old_confirmations: List[community.Confirmation] = []

    @property
    def main_window(self) -> Optional[window.Main]:
        current_window = self.get_window_by_id(self._main_window_id)

        return current_window

    @property
    def steamid(self) -> Optional[universe.SteamId]:
        steamid = config.parser.getint("login", "steamid")

        if steamid:
            try:
                return universe.generate_steamid(steamid)
            except ValueError:
                log.warning(_("SteamId is invalid"))

        return None

    def do_startup(self) -> None:
        Gtk.Application.do_startup(self)

        settings_action = Gio.SimpleAction.new('settings')
        settings_action.connect("activate", self.on_settings_activate)
        self.add_action(settings_action)

        about_action = Gio.SimpleAction.new("about")
        about_action.connect("activate", self.on_about_activate)
        self.add_action(about_action)

        exit_action = Gio.SimpleAction.new("exit")
        exit_action.connect("activate", self.on_exit_activate)
        self.add_action(exit_action)

        theme = config.parser.get("general", "theme")

        if theme == 'dark':
            self.gtk_settings.props.gtk_application_prefer_dark_theme = True
        else:
            self.gtk_settings.props.gtk_application_prefer_dark_theme = False

    def do_activate(self) -> None:
        if self._main_window_id != 0:
            self.main_window.present()
            return

        current_window = window.Main(application=self, title="Steam Tools NG")
        self._main_window_id = current_window.get_id()
        current_window.show()

        loop = asyncio.get_event_loop()
        task = loop.create_task(self.async_activate())
        task.add_done_callback(utils.safe_task_callback)

    async def do_login(self, *, block: bool = True, auto: bool = False) -> None:
        login_dialog = gtk_login.LoginDialog(self.main_window, self)
        login_dialog.set_deletable(False)
        login_dialog.show()

        if auto:
            encrypted_password = config.parser.get("login", "password")
            login_dialog.set_password(encrypted_password)
            login_dialog.login_button.emit('clicked')

        if block:
            while self.main_window.get_realized():
                if login_dialog.has_user_data:
                    break

                await asyncio.sleep(1)

    async def async_activate(self) -> None:
        assert isinstance(self.main_window, window.Main)
        login_session = await login.Login.new_session(0, api_url=self.api_url)

        self.main_window.statusbar.set_warning("steamguard", _("Logging on Steam. Please wait!"))
        log.info(_("Logging on Steam"))

        token = config.parser.get("login", "token")
        token_secure = config.parser.get("login", "token_secure")

        if not token or not token_secure or not self.steamid:
            await self.do_login()

        login_session.restore_login(self.steamid, token, token_secure)

        try:
            if await login_session.is_logged_in(self.steamid):
                log.info("Steam login Successful")
            else:
                await self.do_login(auto=True)
        except aiohttp.ClientError as error:
            log.exception(str(error))
            self.main_window.statusbar.set_critical("steamguard", _("Check your connection. (server down?)"))
            await asyncio.sleep(10)
            return  # FIXME: RETRY ###

        self.main_window.statusbar.clear("steamguard")

        community_session = await community.Community.new_session(0, api_url=self.api_url)

        try:
            api_key = await community_session.get_api_key()
            log.debug(_('SteamAPI key found: %s'), api_key)

            if api_key[1] != 'Steam Tools NG':
                raise AttributeError
        except AttributeError:
            self.main_window.statusbar.set_warning('steamguard', _('Updating your SteamAPI dev key'))
            await asyncio.sleep(3)
            await community_session.revoke_api_key()
            await asyncio.sleep(3)
            api_key = await community_session.register_api_key('Steam Tools NG')
            self.main_window.statusbar.clear('steamguard')

            if not api_key:
                utils.fatal_error_dialog(ValueError(_('Something wrong with your SteamAPI dev key')), [])

        webapi_session = await webapi.SteamWebAPI.new_session(0, api_key=api_key[0], api_url=self.api_url)
        internals_session = await internals.Internals.new_session(0)

        modules: Dict[str, asyncio.Task[Any]] = {}

        while self.main_window.get_realized():
            for module_name in config.plugins.keys():
                task = modules.get(module_name, None)

                if config.parser.getboolean(module_name, "enable"):
                    if task:
                        if task.cancelled() and not task._exception:  # why task.exception() is raising?
                            log.debug(_("%s is requesting a reinitialization."), module_name)
                            modules.pop(module_name)

                        await asyncio.sleep(1)
                    else:
                        log.debug(_("%s is enabled but not initialized. Initializing now."), module_name)
                        module = getattr(self, f"run_{module_name}")

                        if module_name in ["steamgifts", "steamtrades"]:
                            plugin = plugins.get_plugin(module_name)

                            with contextlib.suppress(IndexError):
                                await plugin.Main.new_session(0)

                        if module_name == "coupons":
                            task = asyncio.create_task(module(self.main_window.fetch_coupon_event))
                        elif module_name == "confirmations":
                            task = asyncio.create_task(module())
                        else:
                            self.main_window.set_status(module_name, status=_("Loading"))
                            play_event = self.main_window.get_play_event(module_name)
                            task = asyncio.create_task(module(play_event))

                        log.debug(_("Adding a new callback for %s"), task)
                        task.add_done_callback(utils.safe_task_callback)
                        modules[module_name] = task

                    continue

                if task and not task.cancelled():
                    log.debug(_("%s is disabled but not cancelled. Cancelling now."), module_name)
                    task.cancel()

                    try:
                        await task
                    except asyncio.CancelledError:
                        if module_name not in ["confirmations", "coupons"]:
                            self.main_window.set_status(module_name, status=_("Disabled"))
                else:
                    await asyncio.sleep(1)

    @while_window_realized
    async def run_steamguard(self, play_event: asyncio.Event) -> None:
        await play_event.wait()
        steamguard = core.steamguard.main()

        async for module_data in steamguard:
            self.main_window.set_status("steamguard", module_data)

    @while_window_realized
    async def run_cardfarming(self, play_event: asyncio.Event) -> None:
        cardfarming = core.cardfarming.main(self.steamid)

        async for module_data in cardfarming:
            self.main_window.set_status("cardfarming", module_data)

            if module_data.action == "check":
                executors = module_data.raw_data

                if not play_event.is_set():
                    for executor in executors:
                        executor.shutdown()
                        # TODO: On Windows processes can't answer too fast due executor workaround
                        await asyncio.sleep(1)

                    await play_event.wait()

                    for executor in executors:
                        executor.__init__(executor.appid)

    @while_window_realized
    async def run_confirmations(self) -> None:
        confirmations = core.confirmations.main(self.steamid)

        async for module_data in confirmations:
            if module_data.error:
                self.main_window.statusbar.set_critical('confirmations', module_data.error)
            else:
                self.main_window.statusbar.clear('confirmations')

            if self.main_window.confirmations_tree.lock:
                await self.main_window.confirmations_tree.wait_available()
                continue

            if module_data.action == "login":
                await self.do_login(auto=True)
                continue

            if module_data.action == "update":
                self.main_window.statusbar.set_warning("confirmations", "Updating now!")
                if module_data.raw_data == self.old_confirmations:
                    log.debug(_("Skipping confirmations update because data doesn't seem to have changed"))
                    self.main_window.statusbar.clear('confirmations')
                    continue

                self.main_window.confirmations_tree.store.clear()

                for confirmation_ in module_data.raw_data:
                    # translatable strings
                    t_give = utils.sanitize_confirmation(confirmation_.give)
                    t_receive = utils.sanitize_confirmation(confirmation_.receive)

                    iter_ = self.main_window.confirmations_tree.store.append(None, [
                        str(confirmation_.confid),
                        str(confirmation_.creatorid),
                        str(confirmation_.key),
                        utils.markup(t_give),
                        utils.markup(confirmation_.to),
                        utils.markup(t_receive),
                    ])

                    for item in itertools.zip_longest(confirmation_.give, confirmation_.receive):
                        row = ['', '', '', item[0], '-->', item[1] if item[1] else 'Nothing']
                        self.main_window.confirmations_tree.store.append(iter_, row)

                self.old_confirmations = module_data.raw_data
                self.main_window.statusbar.clear('confirmations')

    @while_window_realized
    async def run_coupons(self, play_event: asyncio.Event) -> None:
        coupons = core.coupons.main(self.steamid, self.main_window.fetch_coupon_event)

        async for module_data in coupons:
            self.main_window.statusbar.clear("coupons")
            await play_event.wait()

            if module_data.error:
                self.main_window.statusbar.set_critical("coupons", module_data.error)

            if module_data.info:
                self.main_window.statusbar.set_warning("coupons", module_data.info)

            if not any([module_data.info, module_data.error]):
                self.main_window.statusbar.clear("coupons")

            if module_data.action == "update":
                iter_ = self.main_window.coupons_tree.store.append([
                    f"{module_data.raw_data['price']:.2f}",
                    utils.markup(module_data.raw_data['name'], foreground='blue', underline='single'),
                    module_data.raw_data['link'],
                    module_data.raw_data['botid'],
                    module_data.raw_data['token'],
                    str(module_data.raw_data['assetid']),
                ])

            if module_data.action == "clear":
                self.main_window.coupons_tree.store.clear()

            if module_data.action == "update_level":
                self.main_window.coupon_progress.set_value(module_data.raw_data[0])
                self.main_window.coupon_progress.set_max_value(module_data.raw_data[1])

    @while_window_realized
    async def run_steamtrades(self, play_event: asyncio.Event) -> None:
        await play_event.wait()
        steamtrades = core.steamtrades.main()

        async for module_data in steamtrades:
            self.main_window.set_status("steamtrades", module_data)

            if module_data.action == "login":
                await self.do_login(auto=True)
                continue

    @while_window_realized
    async def run_steamgifts(self, play_event: asyncio.Event) -> None:
        await play_event.wait()
        steamgifts = core.steamgifts.main()

        async for module_data in steamgifts:
            self.main_window.set_status("steamgifts", module_data)

            if module_data.action == "login":
                await self.do_login(auto=True)
                continue

    def on_settings_activate(self, *args: Any) -> None:
        settings_dialog = settings.SettingsDialog(self.main_window, self)
        settings_dialog.show()

    def on_about_activate(self, *args: Any) -> None:
        dialog = about.AboutDialog(self.main_window)
        dialog.show()

    # noinspection PyMethodMayBeStatic
    def on_exit_activate(self, *args: Any) -> None:
        loop = asyncio.get_running_loop()
        loop.stop()
        # self.main_window.destroy()



#!/usr/bin/env python
#
# Lara Maia <dev@lara.monster> 2015 ~ 2023
#
# The Steam Tools NG is free software: you can redistribute it and/or
# modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation, either version 3 of
# the License, or (at your option) any later version.
#
# The Steam Tools NG is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see http://www.gnu.org/licenses/.
#

import certifi
import os
import subprocess
import sys
import sysconfig
from pathlib import Path
from setuptools import find_packages
from setuptools.command.build_py import build_py
from typing import Any, List, Mapping, Tuple

if os.name == 'nt' and not os.getenv('NO_FREEZE'):
    # noinspection PyPackageRequirements
    from cx_Freeze import setup, Executable
else:
    from setuptools import setup


class BuildTranslations(build_py):
    def run(self) -> None:
        super().run()

        po_build_path = Path('build', 'lib', 'steam_tools_ng', 'locale')
        po_build_path.mkdir(exist_ok=True)

        if 'MSC ' in sys.version:
            # windows
            msgfmt_path = Path(sysconfig.get_path('platlib')).parent.parent.resolve() / 'Tools' / 'i18n' / 'msgfmt.py'
            msgfmt_executor = [sys.executable, msgfmt_path]
        else:
            # mingw/linux
            msgfmt_executor = ['msgfmt']

        for path in Path('i18n').glob('*.po'):
            language = path.stem
            output_directory = po_build_path / language / 'LC_MESSAGES'
            output_directory.mkdir(exist_ok=True, parents=True)
            subprocess.run(msgfmt_executor + ['-o', output_directory / 'steam-tools-ng.mo', path], check=True)


def fix_gtk() -> List[Tuple[str, str]]:
    namespace_packages = [
        'Gtk-4.0',
        'Gdk-4.0',
        'Gsk-4.0',
        'GObject-2.0',
        'GLib-2.0',
        'Gio-2.0',
        'Pango-1.0',
        'PangoCairo-1.0',
        'cairo-1.0',
        'GdkPixbuf-2.0',
        'GModule-2.0',
        'HarfBuzz-0.0',
        'Graphene-1.0',
        'freetype2-2.0',
    ]

    includes = []

    if 'MSC ' in sys.version:
        # windows
        from gi.repository import Gtk
        lib_path = Path(Gtk.__path__[0]).parent.parent.resolve()
        bin_path = lib_path.parent.resolve() / 'bin'

        required_dlls = [
            'gtk-4-1',
            'pango-1.0-0',
            'pangocairo-1.0-0',
            'pangowin32-1.0-0',
            'Rsvg-2.0-vs17',
            'graphene-1.0-0',
            'freetype-6',
        ]

        pixbuf_loaders = [
            'libpixbufloader-svg',
        ]
    else:
        # mingw
        lib_path = Path(sysconfig.get_path('platlib')).parent.parent.resolve()
        bin_path = lib_path.parent.resolve() / 'bin'

        required_dlls = [
            'libgtk-4-1',
            'libpango-1.0-0',
            'libpangocairo-1.0-0',
            'libpangowin32-1.0-0',
            'librsvg-2-2',
            'libgraphene-1.0-0',
            'libfreetype-6',
        ]

        pixbuf_loaders = [
            'libpixbufloader-png',
            'libpixbufloader-svg',
        ]

    for package in namespace_packages:
        includes.append((
            str(lib_path / 'girepository-1.0' / f'{package}.typelib'),
            str(Path('lib', 'girepository-1.0', f'{package}.typelib')),
        ))

    for dll in required_dlls:
        includes.append((
            str(bin_path / f'{dll}.dll'),
            f'{dll}.dll',
        ))

    for loader in pixbuf_loaders:
        includes.append((
            str(lib_path / 'gdk-pixbuf-2.0' / '2.10.0' / 'loaders' / f'{loader}.dll'),
            str(Path('lib', 'gdk-pixbuf-2.0', '2.10.0', 'loaders', f'{loader}.dll')),
        ))

    includes.append((
        str(lib_path / 'gdk-pixbuf-2.0' / '2.10.0' / 'loaders.cache'),
        str(Path('lib', 'gdk-pixbuf-2.0', '2.10.0', 'loaders.cache')),
    ))

    includes.append((
        str(Path('src', 'steam_tools_ng', 'icons', 'settings.ini')),
        str(Path('etc', 'gtk-4.0', 'settings.ini')),
    ))

    return includes


def freeze_options() -> Mapping[str, Any]:
    if os.name != 'nt' or os.getenv('NO_FREEZE'):
        return {}

    icons_path = Path('src', 'steam_tools_ng', 'icons')
    copyright_ = 'Lara Maia (C) 2015 ~ 2023'

    executables = [
        Executable(
            Path("src", "steam_tools_ng", "cli.py"),
            target_name='steam-tools-ng',
            base=None,
            icon=Path(icons_path, 'stng_console.ico'),
            shortcut_name='Steam Tools NG CLI',
            copyright=copyright_,
        ),
        Executable(
            Path("src", "steam_tools_ng", "gui.py"),
            target_name='steam-tools-ng-gui',
            base=None,
            icon=Path(icons_path, 'stng.ico'),
            shortcut_name='Steam Tools NG GUI',
            copyright=copyright_,
        ),
        Executable(
            Path("src", "steam_tools_ng", "steam_api_executor.py"),
            target_name='steam-api-executor',
            base=None,
            copyright=copyright_,
        )
    ]

    paths = ['src']
    paths.extend(sys.path)

    includes = [*fix_gtk(), (certifi.where(), Path('etc', 'cacert.pem'))]

    for file in Path(icons_path, 'Default').iterdir():
        if file != 'settings.ini':
            includes.append((file, Path('share', 'icons', 'Default', file.name)))

    for language in ['fr', 'pt_BR']:
        language_directory = Path('lib', 'steam_tools_ng', 'locale', language, 'LC_MESSAGES')
        includes.append((
            Path('build', language_directory, 'steam-tools-ng.mo'),
            language_directory / 'steam-tools-ng.mo',
        ))

    build_exe_options = {
        "include_files": includes,
        "path": paths,
    }

    options = {
        "build_exe": build_exe_options,
    }

    return {
        "options": options,
        "executables": executables,
    }

setup(cmdclass={'build_py': BuildTranslations}, **freeze_options())



#!/usr/bin/env python
#
# Lara Maia <dev@lara.monster> 2015 ~ 2023
#
# The Steam Tools NG is free software: you can redistribute it and/or
# modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation, either version 3 of
# the License, or (at your option) any later version.
#
# The Steam Tools NG is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see http://www.gnu.org/licenses/.
#
import aiohttp
import asyncio
from subprocess import call
from typing import AsyncGenerator, Optional, List

from stlib import webapi, client, universe, community
from . import utils
from .. import i18n, config

_ = i18n.get_translation


async def mixing_igredients(ids: List[str]) -> AsyncGenerator[utils.ModuleData, None]:
    yield utils.ModuleData(display=str(34), status=_("Mixing ingredients"))
    await asyncio.sleep(2)

    try:
        for id_ in ids:
            with client.SteamAPIExecutor(int(id_)):
                await asyncio.sleep(2)
                yield utils.ModuleData(display=id_, status=_("Sugar successfully added"))
    except ProcessLookupError:
        yield utils.ModuleData(error=_("Steam Client is not running."))


async def cake(
        webapi_session: webapi.SteamWebAPI,
        steamid: universe.SteamId,
        game_id: int,
) -> AsyncGenerator[utils.ModuleData, None]:
    yield utils.ModuleData(display=str(34), status=_("Loading a delicious cake"))
    ids = config.parser.get('fakerun', 'cakes').strip().split(',')
    call(f'{config.file_manager} "steam://friends/status/invisible"')

    if len(ids) < 3:
        yield utils.ModuleData(error=_("Not enough ingredients"))
        return

    try:
        game_list = await webapi_session.get_owned_games(steamid, appids_filter=[game_id, *ids])

        if len(game_list) != 4:
            raise ValueError
    except aiohttp.ClientError:
        module_data = utils.ModuleData(error=_("Check your connection. (server down?)"))

        async for data in utils.timed_module_data(15, module_data):
            yield data

        return
    except ValueError:
        yield utils.ModuleData(error=_("Some ingredients are missing from your cuisine"))
        return

    call(f'{config.file_manager} "steam://run/{game_id}"')
    await asyncio.sleep(3)

    async for slice_ in mixing_igredients(ids):
        yield slice_

    community_session = community.Community.get_session(0)

    while True:
        last_played_game = await community_session.get_last_played_game(steamid)

        if last_played_game == game_id:
            yield utils.ModuleData(display=str(34), status=_("getting cake out of pan"))

            async for slice_ in mixing_igredients(ids):
                yield slice_

            yield utils.ModuleData(display=str(34), status=_("Cake is ready"))
            break

        await asyncio.sleep(30)


async def main(
        steamid: universe.SteamId,
        game_id: int,
        extra_game_id: Optional[int] = None,
) -> AsyncGenerator[utils.ModuleData, None]:
    webapi_session = webapi.SteamWebAPI.get_session(0)

    if game_id == 34:
        assert isinstance(extra_game_id, int), "No extra game_id"
        async for slice_ in cake(webapi_session, steamid, extra_game_id):
            yield slice_
        return

    try:
        game_list = await webapi_session.get_owned_games(steamid, appids_filter=[game_id])
        game_name = game_list[0].name
    except aiohttp.ClientError:
        module_data = utils.ModuleData(error=_("Check your connection. (server down?)"))

        async for data in utils.timed_module_data(15, module_data):
            yield data

        return
    except ValueError:
        yield utils.ModuleData(error=_("Game {} doesn't exist").format(game_id))
        return

    yield utils.ModuleData(
        display=str(game_id),
        status=_("Loading {}").format(game_name),
    )

    start_time = 0

    try:
        with client.SteamAPIExecutor(game_id) as executor:
            while True:
                yield utils.ModuleData(
                    display=str(game_id),
                    info=_("Running for {} minutes.").format(round(start_time / 60)),
                    status=_("Running {}").format(game_name),
                    raw_data=executor,
                    action="check",
                )
                await asyncio.sleep(1)
                start_time += 1
    except ProcessLookupError:
        yield utils.ModuleData(error=_("Steam Client is not running."))



#!/usr/bin/env python
#
# Lara Maia <dev@lara.monster> 2015 ~ 2023
#
# The Steam Tools NG is free software: you can redistribute it and/or
# modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation, either version 3 of
# the License, or (at your option) any later version.
#
# The Steam Tools NG is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see http://www.gnu.org/licenses/.
#
# FIXME: Workaround for keyboard lag when running games on GUI on Windows
# FIXME: https://gitlab.gnome.org/GNOME/gtk/-/issues/2015
from multiprocessing import freeze_support

import sys
import time

from stlib import client

if __name__ == "__main__":
    freeze_support()

    if len(sys.argv) < 2:
        raise AttributeError('No appid')

    with client.SteamAPIExecutor(int(sys.argv[1])):
        while True:
            time.sleep(5)



#!/usr/bin/env python
#
# Lara Maia <dev@lara.monster> 2015 ~ 2023
#
# The Steam Tools NG is free software: you can redistribute it and/or
# modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation, either version 3 of
# the License, or (at your option) any later version.
#
# The Steam Tools NG is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see http://www.gnu.org/licenses/.
#

from importlib import resources

from gi.repository import Gdk, Gtk

from .. import __version__, i18n

_ = i18n.get_translation


# noinspection PyUnusedLocal
class AboutDialog(Gtk.AboutDialog):
    def __init__(self, parent_window: Gtk.Window) -> None:
        super().__init__()
        self.set_transient_for(parent_window)
        self.set_modal(True)
        self.set_program_name("Steam Tools NG")

        self.set_authors([
            "Lara Maia",
        ])

        self.set_translator_credits(
            "Lara Maia (pt_BR)\n"
            "®omano (fr)"
        )

        self.set_website("https://github.com/calendulish/steam-tools-ng")
        self.set_website_label(_("Git Repository"))
        self.set_version(__version__)
        self.set_copyright("Lara Maia (C) 2015 ~ 2023 - dev@lara.monster")
        self.set_comments(_("Made with Love <3"))
        self.set_license_type(Gtk.License.GPL_3_0)

        with resources.as_file(resources.files('steam_tools_ng')) as path:
            logo = Gdk.Texture.new_from_filename(str(path / 'icons' / 'stng.png'))

        self.set_logo(logo)
        self.present()
